from invenio_records_resources.resources import RecordResource


class DataResource(RecordResource):
    """DataRecord resource."""

    # here you can for example redefine
    # create_url_rules function to add your own rules
